==> v1.0.5.zip: portfolio/web/src/components/Project/NewProject/NewProject.tsx <==
import type {
  CreateProjectMutation,
  CreateProjectInput,
  CreateProjectMutationVariables,
} from 'types/graphql'

import { navigate, routes } from '@redwoodjs/router'
import { useMutation } from '@redwoodjs/web'
import type { TypedDocumentNode } from '@redwoodjs/web'
import { toast } from '@redwoodjs/web/toast'

import ProjectForm from 'src/components/Project/ProjectForm'

const CREATE_PROJECT_MUTATION: TypedDocumentNode<
  CreateProjectMutation,
  CreateProjectMutationVariables
> = gql`
  mutation CreateProjectMutation($input: CreateProjectInput!) {
    createProject(input: $input) {
      id
    }
  }
`

const NewProject = () => {
  const [createProject, { loading, error }] = useMutation(
    CREATE_PROJECT_MUTATION,
    {
      onCompleted: () => {
        toast.success('Project created')
        navigate(routes.adminProjects())
      },
      onError: (error) => toast.error(error.message),
    }
  )

  const onSave = (input: CreateProjectInput) =>
    createProject({ variables: { input } })

  return (
    <div className="flex w-full justify-center">
      <div className="overflow-hidden overflow-x-auto rounded-xl bg-base-100">
        <table className="table w-80">
          <thead className="bg-base-200 font-syne">
            <tr>
              <th>New Project</th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <th>
                <ProjectForm onSave={onSave} error={error} loading={loading} />
              </th>
            </tr>
          </tbody>
        </table>
      </div>
    </div>
  )
}

export default NewProject

==> v1.1.6-1.zip: portfolio/web/src/components/Project/NewProject/NewProject.tsx <==
import type {
  CreateProjectMutation,
  CreateProjectInput,
  CreateProjectMutationVariables,
} from 'types/graphql'

import { navigate, routes } from '@redwoodjs/router'
import { useMutation } from '@redwoodjs/web'
import type { TypedDocumentNode } from '@redwoodjs/web'
import { toast } from '@redwoodjs/web/toast'

import ProjectForm from 'src/components/Project/ProjectForm'

const CREATE_PROJECT_MUTATION: TypedDocumentNode<
  CreateProjectMutation,
  CreateProjectMutationVariables
> = gql`
  mutation CreateProjectMutation($input: CreateProjectInput!) {
    createProject(input: $input) {
      id
    }
  }
`

const NewProject = () => {
  const [createProject, { loading, error }] = useMutation(
    CREATE_PROJECT_MUTATION,
    {
      onCompleted: () => {
        toast.success('Project created')
        navigate(routes.adminProjects())
      },
      onError: (error) => toast.error(error.message),
    }
  )

  const onSave = (input: CreateProjectInput) =>
    createProject({ variables: { input } })

  return (
    <div className="flex mx-auto max-w-prose justify-center">
      <div className="overflow-hidden w-full overflow-x-auto rounded-xl bg-base-100">
        <table className="table">
          <thead className="bg-base-200 font-syne">
            <tr>
              <th>New Project</th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <th>
                <ProjectForm onSave={onSave} error={error} loading={loading} />
              </th>
            </tr>
          </tbody>
        </table>
      </div>
    </div>
  )
}

export default NewProject
